@@ -35,6 +35,8 @@
 #include <QStandardPaths>
 #include <QDebug>
 
+#include <algorithm>
+
 namespace Fm {
 
 FolderItemDelegate::FolderItemDelegate(QAbstractItemView* view, QObject* parent):
@@ -198,8 +200,8 @@ void FolderItemDelegate::paint(QPainter* painter, const QStyleOptionViewItem& op
            && option.decorationSize.width() >= 48 && (opt.state & QStyle::State_MouseOver)) {
             int s = option.decorationSize.width() / 3;
             bool cursorOnSelectionCorner = false;
-            iconPos = QPoint(qMax(opt.rect.x(), iconPos.x() - s),
-                             qMax(opt.rect.y(), iconPos.y() - s));
+            iconPos = QPoint(std::max(opt.rect.x(), iconPos.x() - s),
+                             std::max(opt.rect.y(), iconPos.y() - s));
             QPoint curPos = iv->viewport()->mapFromGlobal(QCursor::pos());
             if(curPos.x() >= iconPos.x() && curPos.x() <= iconPos.x() + s
                && curPos.y() >= iconPos.y() && curPos.y() <= iconPos.y() + s) {
@@ -326,12 +328,12 @@ void FolderItemDelegate::drawText(QPainter* painter, QStyleOptionViewItem& opt,
             break;
         }
         height += line.height();
-        width = qMax(width, line.naturalTextWidth());
+        width = std::max(width, line.naturalTextWidth());
         ++ visibleLines;
     }
     layout.endLayout();
 
-    width = qMax(width, static_cast<qreal>(opt.fontMetrics.horizontalAdvance(elidedText)));
+    width = std::max(width, static_cast<qreal>(opt.fontMetrics.horizontalAdvance(elidedText)));
 
     // draw background for selected item
     QRectF boundRect = layout.boundingRect();
@@ -474,24 +476,24 @@ void FolderItemDelegate::setEditorData(QWidget* editor, const QModelIndex& index
         // select text appropriately
         QTextCursor cur = textEdit->textCursor();
         int end;
-        if (index.data(Fm::FolderModel::FileIsDirRole).toBool() || !currentName.contains(QLatin1String("."))) {
+        if (index.data(Fm::FolderModel::FileIsDirRole).toBool() || !currentName.contains(QLatin1StringView("."))) {
             end = currentName.size();
         }
         else {
-            end = currentName.lastIndexOf(QLatin1String("."));
+            end = currentName.lastIndexOf(QLatin1StringView("."));
         }
         cur.setPosition(end, QTextCursor::KeepAnchor);
         textEdit->setTextCursor(cur);
     }
     else if (QLineEdit* lineEdit = qobject_cast<QLineEdit*>(editor)) {
         lineEdit->setText(currentName);
-        if (!index.data(Fm::FolderModel::FileIsDirRole).toBool() && currentName.contains(QLatin1String(".")))
+        if (!index.data(Fm::FolderModel::FileIsDirRole).toBool() && currentName.contains(QLatin1StringView(".")))
         {
             /* Qt will call QLineEdit::selectAll() after calling setEditorData() in
                qabstractitemview.cpp -> QAbstractItemViewPrivate::editor(). Therefore,
                we cannot select a part of the text in the usual way here.  */
             QTimer::singleShot(0, lineEdit, [lineEdit]() {
-                int length = lineEdit->text().lastIndexOf(QLatin1String("."));
+                int length = lineEdit->text().lastIndexOf(QLatin1StringView("."));
                 lineEdit->setSelection(0, length);
             });
         }
