@@ -1007,12 +1007,12 @@ Möchtest Sie sie stattdessen löschen?</translation>
 <context>
     <name>Fm::FileTransferJob</name>
     <message>
-        <location filename="../core/filetransferjob.cpp" line="486"/>
+        <location filename="../core/filetransferjob.cpp" line="492"/>
         <source>Cannot copy a directory into itself!</source>
         <translation>Verzeichnis kann nicht in sich selbst kopiert werden!</translation>
     </message>
     <message>
-        <location filename="../core/filetransferjob.cpp" line="537"/>
+        <location filename="../core/filetransferjob.cpp" line="543"/>
         <source>Cannot create a link on non-native filesystem</source>
         <translation>Kann keine Verknüpfung auf einem nicht-nativen Dateisystem erstellen</translation>
     </message>
@@ -1322,7 +1322,7 @@ Möchtest Sie sie stattdessen löschen?</translation>
     </message>
     <message>
         <location filename="../placesview.cpp" line="600"/>
-        <location filename="../placesview.cpp" line="662"/>
+        <location filename="../placesview.cpp" line="667"/>
         <source>Hide</source>
         <translation>Ausblenden</translation>
     </message>
@@ -1348,7 +1348,7 @@ Möchtest Sie sie stattdessen löschen?</translation>
     </message>
     <message>
         <location filename="../placesview.cpp" line="643"/>
-        <location filename="../placesview.cpp" line="676"/>
+        <location filename="../placesview.cpp" line="681"/>
         <source>Unmount</source>
         <translation>Aushängen</translation>
     </message>
@@ -1363,7 +1363,12 @@ Möchtest Sie sie stattdessen löschen?</translation>
         <translation>Auswerfen</translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="688"/>
+        <location filename="../placesview.cpp" line="658"/>
+        <source>Safely Remove</source>
+        <translation>Sicher entfernen</translation>
+    </message>
+    <message>
+        <location filename="../placesview.cpp" line="693"/>
         <source>Show All Entries</source>
         <translation>Alle Einträge anzeigen</translation>
     </message>
@@ -1422,7 +1427,7 @@ Geändert: %2</translation>
     <message>
         <location filename="../core/untrashjob.cpp" line="35"/>
         <source>Cannot untrash file &apos;%s&apos;: original path not known</source>
-        <translation>Datei &apos;1%&apos; ist aus dem Papierkorb nicht wiederherstellbar: ursprünglicher Pfad nicht bekannt</translation>
+        <translation>Datei &apos;%s&apos; ist aus dem Papierkorb nicht wiederherstellbar: ursprünglicher Pfad nicht bekannt</translation>
     </message>
 </context>
 <context>
@@ -1483,7 +1488,7 @@ Geändert: %2</translation>
     <message>
         <location filename="../filelauncher.cpp" line="124"/>
         <location filename="../filepropsdialog.cpp" line="674"/>
-        <location filename="../mountoperation.cpp" line="297"/>
+        <location filename="../mountoperation.cpp" line="315"/>
         <location filename="../utilities.cpp" line="154"/>
         <location filename="../utilities.cpp" line="318"/>
         <source>Error</source>
@@ -1547,7 +1552,7 @@ Geändert: %2</translation>
     <message>
         <location filename="../core/basicfilelauncher.cpp" line="319"/>
         <source>Invalid desktop entry file: &apos;%1&apos;</source>
-        <translation>Ungültige Arbeitsflächeneintragsdatei: &apos;1%&apos;</translation>
+        <translation>Ungültige Arbeitsflächeneintragsdatei: &apos;%1&apos;</translation>
     </message>
     <message>
         <location filename="../core/basicfilelauncher.cpp" line="355"/>
