@@ -960,7 +960,7 @@ Do you want to delete them instead?</source>
         <source>%Ln files</source>
         <translation>
             <numerusform>קובץ %Ln</numerusform>
-            <numerusform>%Ln קבצים</numerusform>
+            <numerusform>שני קבצים</numerusform>
         </translation>
     </message>
     <message>
@@ -1007,12 +1007,12 @@ Do you want to delete them instead?</source>
 <context>
     <name>Fm::FileTransferJob</name>
     <message>
-        <location filename="../core/filetransferjob.cpp" line="486"/>
+        <location filename="../core/filetransferjob.cpp" line="492"/>
         <source>Cannot copy a directory into itself!</source>
         <translation>לא ניתן להעתיק תיקייה לתוך עצמה!</translation>
     </message>
     <message>
-        <location filename="../core/filetransferjob.cpp" line="537"/>
+        <location filename="../core/filetransferjob.cpp" line="543"/>
         <source>Cannot create a link on non-native filesystem</source>
         <translation>לא ניתן ליצור קישור על מערכת קישור בלתי טבעית</translation>
     </message>
@@ -1322,7 +1322,7 @@ Do you want to delete them instead?</source>
     </message>
     <message>
         <location filename="../placesview.cpp" line="600"/>
-        <location filename="../placesview.cpp" line="662"/>
+        <location filename="../placesview.cpp" line="667"/>
         <source>Hide</source>
         <translation>הסתרה</translation>
     </message>
@@ -1348,7 +1348,7 @@ Do you want to delete them instead?</source>
     </message>
     <message>
         <location filename="../placesview.cpp" line="643"/>
-        <location filename="../placesview.cpp" line="676"/>
+        <location filename="../placesview.cpp" line="681"/>
         <source>Unmount</source>
         <translation>ניתוק עיגון</translation>
     </message>
@@ -1363,7 +1363,12 @@ Do you want to delete them instead?</source>
         <translation>שליפה</translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="688"/>
+        <location filename="../placesview.cpp" line="658"/>
+        <source>Safely Remove</source>
+        <translation>הסרה בבטחה</translation>
+    </message>
+    <message>
+        <location filename="../placesview.cpp" line="693"/>
         <source>Show All Entries</source>
         <translation>הצגת כל הרשומות</translation>
     </message>
@@ -1493,7 +1498,7 @@ Modified: %2</source>
     <message>
         <location filename="../filelauncher.cpp" line="124"/>
         <location filename="../filepropsdialog.cpp" line="674"/>
-        <location filename="../mountoperation.cpp" line="297"/>
+        <location filename="../mountoperation.cpp" line="315"/>
         <location filename="../utilities.cpp" line="154"/>
         <location filename="../utilities.cpp" line="318"/>
         <source>Error</source>
