@@ -329,7 +329,7 @@
     <message>
         <location filename="../file-props.ui" line="749"/>
         <source>Sticky</source>
-        <translation></translation>
+        <translation>Ragadós</translation>
     </message>
     <message>
         <location filename="../file-props.ui" line="756"/>
@@ -673,7 +673,7 @@ Le szeretné cserélni?</translation>
         <location filename="../filemenu.cpp" line="420"/>
         <source>Do you want to open these %1 files?</source>
         <translation>
-            <numerusform>Meg szeretné nyitni ezt a %s fájlt?</numerusform>
+            <numerusform>Meg szeretné nyitni ezt a fájlt?</numerusform>
         </translation>
     </message>
     <message>
@@ -1003,12 +1003,12 @@ Szeretné véglegesen törölni őket?</translation>
 <context>
     <name>Fm::FileTransferJob</name>
     <message>
-        <location filename="../core/filetransferjob.cpp" line="486"/>
+        <location filename="../core/filetransferjob.cpp" line="492"/>
         <source>Cannot copy a directory into itself!</source>
         <translation>Könyvtár nem másolható önmagába!</translation>
     </message>
     <message>
-        <location filename="../core/filetransferjob.cpp" line="537"/>
+        <location filename="../core/filetransferjob.cpp" line="543"/>
         <source>Cannot create a link on non-native filesystem</source>
         <translation>Nem lehet linket létrehozni nem helyi fájlrendszeren</translation>
     </message>
@@ -1018,7 +1018,7 @@ Szeretné véglegesen törölni őket?</translation>
     <message>
         <location filename="../foldermenu.cpp" line="58"/>
         <source>Empty Trash</source>
-        <translation type="unfinished">Kuka ürítése</translation>
+        <translation>Kuka ürítése</translation>
     </message>
     <message>
         <location filename="../foldermenu.cpp" line="70"/>
@@ -1318,7 +1318,7 @@ Szeretné véglegesen törölni őket?</translation>
     </message>
     <message>
         <location filename="../placesview.cpp" line="600"/>
-        <location filename="../placesview.cpp" line="662"/>
+        <location filename="../placesview.cpp" line="667"/>
         <source>Hide</source>
         <translation>Elrejtés</translation>
     </message>
@@ -1344,7 +1344,7 @@ Szeretné véglegesen törölni őket?</translation>
     </message>
     <message>
         <location filename="../placesview.cpp" line="643"/>
-        <location filename="../placesview.cpp" line="676"/>
+        <location filename="../placesview.cpp" line="681"/>
         <source>Unmount</source>
         <translation>Lecsatolás</translation>
     </message>
@@ -1359,7 +1359,12 @@ Szeretné véglegesen törölni őket?</translation>
         <translation>Kiadás</translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="688"/>
+        <location filename="../placesview.cpp" line="658"/>
+        <source>Safely Remove</source>
+        <translation>Biztonságos eltávolítás</translation>
+    </message>
+    <message>
+        <location filename="../placesview.cpp" line="693"/>
         <source>Show All Entries</source>
         <translation>Minden bejegyzés megjelenítése</translation>
     </message>
@@ -1489,7 +1494,7 @@ Módosítva: %2</translation>
     <message>
         <location filename="../filelauncher.cpp" line="124"/>
         <location filename="../filepropsdialog.cpp" line="674"/>
-        <location filename="../mountoperation.cpp" line="297"/>
+        <location filename="../mountoperation.cpp" line="315"/>
         <location filename="../utilities.cpp" line="154"/>
         <location filename="../utilities.cpp" line="318"/>
         <source>Error</source>
