@@ -1007,12 +1007,12 @@ Fayiro ezo zo nzigyeewobugyi?</translation>
 <context>
     <name>Fm::FileTransferJob</name>
     <message>
-        <location filename="../core/filetransferjob.cpp" line="486"/>
+        <location filename="../core/filetransferjob.cpp" line="492"/>
         <source>Cannot copy a directory into itself!</source>
         <translation>Koppi y&apos;etterekero tesobola okugenda mu tterekero eryo!</translation>
     </message>
     <message>
-        <location filename="../core/filetransferjob.cpp" line="537"/>
+        <location filename="../core/filetransferjob.cpp" line="543"/>
         <source>Cannot create a link on non-native filesystem</source>
         <translation>Sisobola okukolera nyunzi mu kifo ekitegekedwa mu nkola etakwatagana ne sisitemu eno</translation>
     </message>
@@ -1322,7 +1322,7 @@ Fayiro ezo zo nzigyeewobugyi?</translation>
     </message>
     <message>
         <location filename="../placesview.cpp" line="600"/>
-        <location filename="../placesview.cpp" line="662"/>
+        <location filename="../placesview.cpp" line="667"/>
         <source>Hide</source>
         <translation>Kisa</translation>
     </message>
@@ -1348,7 +1348,7 @@ Fayiro ezo zo nzigyeewobugyi?</translation>
     </message>
     <message>
         <location filename="../placesview.cpp" line="643"/>
-        <location filename="../placesview.cpp" line="676"/>
+        <location filename="../placesview.cpp" line="681"/>
         <source>Unmount</source>
         <translation>Wangula</translation>
     </message>
@@ -1363,7 +1363,12 @@ Fayiro ezo zo nzigyeewobugyi?</translation>
         <translation>Wandula</translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="688"/>
+        <location filename="../placesview.cpp" line="658"/>
+        <source>Safely Remove</source>
+        <translation>Wandula Ekitereka Data Ekigyikamu</translation>
+    </message>
+    <message>
+        <location filename="../placesview.cpp" line="693"/>
         <source>Show All Entries</source>
         <translation>Laga ebirimu byonna</translation>
     </message>
@@ -1493,7 +1498,7 @@ Amakyusa: %2</translation>
     <message>
         <location filename="../filelauncher.cpp" line="124"/>
         <location filename="../filepropsdialog.cpp" line="674"/>
-        <location filename="../mountoperation.cpp" line="297"/>
+        <location filename="../mountoperation.cpp" line="315"/>
         <location filename="../utilities.cpp" line="154"/>
         <location filename="../utilities.cpp" line="318"/>
         <source>Error</source>
