@@ -673,7 +673,7 @@ Değiştirmek istiyor musunuz?</translation>
         <location filename="../filemenu.cpp" line="420"/>
         <source>Do you want to open these %1 files?</source>
         <translation>
-            <numerusform>Bu %1 dosyasını açmak istiyor musunuz?</numerusform>
+            <numerusform>Bu dosyayı açmak istiyor musunuz?</numerusform>
         </translation>
     </message>
     <message>
@@ -956,7 +956,7 @@ Onun yerine silmek ister misiniz?</translation>
         <location filename="../filepropsdialog.cpp" line="461"/>
         <source>%Ln files</source>
         <translation>
-            <numerusform>%Ln dosyası</numerusform>
+            <numerusform>1 dosya</numerusform>
         </translation>
     </message>
     <message>
@@ -1003,12 +1003,12 @@ Onun yerine silmek ister misiniz?</translation>
 <context>
     <name>Fm::FileTransferJob</name>
     <message>
-        <location filename="../core/filetransferjob.cpp" line="486"/>
+        <location filename="../core/filetransferjob.cpp" line="492"/>
         <source>Cannot copy a directory into itself!</source>
         <translation>Bir dizin kendi kendine kopyalanamaz!</translation>
     </message>
     <message>
-        <location filename="../core/filetransferjob.cpp" line="537"/>
+        <location filename="../core/filetransferjob.cpp" line="543"/>
         <source>Cannot create a link on non-native filesystem</source>
         <translation>Yerel olmayan dosya sisteminde bağlantı oluşturulamıyor</translation>
     </message>
@@ -1318,7 +1318,7 @@ Onun yerine silmek ister misiniz?</translation>
     </message>
     <message>
         <location filename="../placesview.cpp" line="600"/>
-        <location filename="../placesview.cpp" line="662"/>
+        <location filename="../placesview.cpp" line="667"/>
         <source>Hide</source>
         <translation>Gizle</translation>
     </message>
@@ -1344,7 +1344,7 @@ Onun yerine silmek ister misiniz?</translation>
     </message>
     <message>
         <location filename="../placesview.cpp" line="643"/>
-        <location filename="../placesview.cpp" line="676"/>
+        <location filename="../placesview.cpp" line="681"/>
         <source>Unmount</source>
         <translation>Ayır</translation>
     </message>
@@ -1359,7 +1359,12 @@ Onun yerine silmek ister misiniz?</translation>
         <translation>Çıkart</translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="688"/>
+        <location filename="../placesview.cpp" line="658"/>
+        <source>Safely Remove</source>
+        <translation>Güvenle Kaldır</translation>
+    </message>
+    <message>
+        <location filename="../placesview.cpp" line="693"/>
         <source>Show All Entries</source>
         <translation>Tüm Girdileri Göster</translation>
     </message>
@@ -1489,7 +1494,7 @@ Değiştirild: %2</translation>
     <message>
         <location filename="../filelauncher.cpp" line="124"/>
         <location filename="../filepropsdialog.cpp" line="674"/>
-        <location filename="../mountoperation.cpp" line="297"/>
+        <location filename="../mountoperation.cpp" line="315"/>
         <location filename="../utilities.cpp" line="154"/>
         <location filename="../utilities.cpp" line="318"/>
         <source>Error</source>
