@@ -1003,12 +1003,12 @@ Do you want to delete them instead?</source>
 <context>
     <name>Fm::FileTransferJob</name>
     <message>
-        <location filename="../core/filetransferjob.cpp" line="486"/>
+        <location filename="../core/filetransferjob.cpp" line="492"/>
         <source>Cannot copy a directory into itself!</source>
         <translation>无法将目录复制到自身！</translation>
     </message>
     <message>
-        <location filename="../core/filetransferjob.cpp" line="537"/>
+        <location filename="../core/filetransferjob.cpp" line="543"/>
         <source>Cannot create a link on non-native filesystem</source>
         <translation>无法在非原生文件系统中创建链接</translation>
     </message>
@@ -1318,7 +1318,7 @@ Do you want to delete them instead?</source>
     </message>
     <message>
         <location filename="../placesview.cpp" line="600"/>
-        <location filename="../placesview.cpp" line="662"/>
+        <location filename="../placesview.cpp" line="667"/>
         <source>Hide</source>
         <translation>隐藏</translation>
     </message>
@@ -1344,7 +1344,7 @@ Do you want to delete them instead?</source>
     </message>
     <message>
         <location filename="../placesview.cpp" line="643"/>
-        <location filename="../placesview.cpp" line="676"/>
+        <location filename="../placesview.cpp" line="681"/>
         <source>Unmount</source>
         <translation>卸载</translation>
     </message>
@@ -1359,7 +1359,12 @@ Do you want to delete them instead?</source>
         <translation>弹出</translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="688"/>
+        <location filename="../placesview.cpp" line="658"/>
+        <source>Safely Remove</source>
+        <translation>安全移除</translation>
+    </message>
+    <message>
+        <location filename="../placesview.cpp" line="693"/>
         <source>Show All Entries</source>
         <translation>显示所有快捷方式</translation>
     </message>
@@ -1489,7 +1494,7 @@ Modified: %2</source>
     <message>
         <location filename="../filelauncher.cpp" line="124"/>
         <location filename="../filepropsdialog.cpp" line="674"/>
-        <location filename="../mountoperation.cpp" line="297"/>
+        <location filename="../mountoperation.cpp" line="315"/>
         <location filename="../utilities.cpp" line="154"/>
         <location filename="../utilities.cpp" line="318"/>
         <source>Error</source>
